@@ -25,6 +25,12 @@ sub handler {
 
     # Do something and return a PSGI response
     # NB: $req is a Lemonldap::NG::Common::PSGI::Request object
+    $self->logger->notice("Request handled by TestPsgi handler");
+    $self->userLogger->info("User logger trace");
+
+
+    $self->auditLog( $req, message => "audit" );
+    $self->auditLog( $req, field1 => "one", field2 => "two" );
 
     return [ 200, [ 'Content-Type' => 'text/plain' ], ['Body lines'] ];
 }
